@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,10 +57,12 @@ import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.util.Properties;
+import javax.mail.AuthenticationFailedException;
 import javax.mail.MessagingException;
 import javax.mail.NoSuchProviderException;
 import javax.mail.Session;
 import javax.mail.Store;
+import javax.mail.internet.IDNA;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import com.openexchange.authentication.Authenticated;
@@ -101,7 +103,7 @@ public class IMAPAuthentication implements AuthenticationService {
         }
     }
 
-    private static final Log LOG = LogFactory.getLog(IMAPAuthentication.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(IMAPAuthentication.class));
 
     private static Properties props;
 
@@ -182,7 +184,7 @@ public class IMAPAuthentication implements AuthenticationService {
             }
 
             if (props.get(PropertyNames.IMAP_SERVER.name) != null) {
-                host = (String) props.get(PropertyNames.IMAP_SERVER.name);
+                host = IDNA.toASCII((String) props.get(PropertyNames.IMAP_SERVER.name));
             }
 
             if (props.get(PropertyNames.IMAP_PORT.name) != null) {
@@ -210,6 +212,7 @@ public class IMAPAuthentication implements AuthenticationService {
 
                     final int ctxId = contextService.getContextId(splitted[0]);
                     if (ContextStorage.NOT_FOUND == ctxId) {
+                        LOG.error("Context id=" + ctxId + " not found");
                         throw INVALID_CREDENTIALS.create();
                     }
                     final Context ctx = contextService.getContext(ctxId);
@@ -219,10 +222,11 @@ public class IMAPAuthentication implements AuthenticationService {
                     try {
                         userId = userService.getUserId(uid, ctx);
                     } catch (final UserException e) {
+                        LOG.error(e.toString(),e);
                         throw INVALID_CREDENTIALS.create();
                     }
                     // final User user2 = userService.getUser(userId, ctx);
-                    
+
                     /*
                      * Load primary account and check its protocol to be IMAP
                      */
@@ -249,15 +253,18 @@ public class IMAPAuthentication implements AuthenticationService {
                     /*
                      * Get IMAP server from primary account
                      */
-                    host = defaultMailAccount.getMailServer();
+                    host = IDNA.toASCII(defaultMailAccount.getMailServer());
                     port = defaultMailAccount.getMailPort();
                     USE_IMAPS = defaultMailAccount.isMailSecure();
                     LOG.debug("Parsed IMAP Infos: " + (USE_IMAPS ? "imaps" : "imap") + " " + host + " " + port + "  (" + userId + "@" + ctxId + ")");
                 } catch (final ContextException e) {
+                    LOG.error(e.toString(),e);
                     throw new LoginException(e);
                 } catch (final ServiceException e) {
+                    LOG.error(e.toString(),e);
                     throw new LoginException(e);
                 } catch (final MailAccountException e) {
+                    LOG.error(e.toString(),e);
                     throw new LoginException(e);
                 }
 
@@ -344,10 +351,14 @@ public class IMAPAuthentication implements AuthenticationService {
         } catch (final NoSuchProviderException e) {
             LOG.error("Error setup initial imap envorinment!", e);
             throw LoginExceptionCodes.COMMUNICATION.create(e);
-        } catch (final MessagingException e) {
+        } catch (final AuthenticationFailedException e) {
             LOG.info("Authentication error on host " + host + ":" + port + " for user " + user, e);
-            LOG.debug("Debug imap authentication, e");
+            LOG.debug("Debug imap authentication", e);
             throw LoginExceptionCodes.INVALID_CREDENTIALS.create(e);
+        } catch (final MessagingException e) {
+            LOG.info("Messaging error on host " + host + ":" + port + " for user " + user, e);
+            LOG.debug("Debug imap error", e);
+            throw LoginExceptionCodes.UNKNOWN.create(e, e.getMessage());
         } finally {
             try {
                 if (imapconnection != null) {
@@ -393,7 +404,7 @@ public class IMAPAuthentication implements AuthenticationService {
 
     /**
      * Splits user name and context.
-     * 
+     *
      * @param loginInfo combined information separated by an @ sign.
      * @return a string array with context and user name (in this order).
      */
@@ -403,7 +414,7 @@ public class IMAPAuthentication implements AuthenticationService {
 
     /**
      * Splits user name and context.
-     * 
+     *
      * @param loginInfo combined information separated by an @ sign.
      * @param separator for splitting user name and context.
      * @return a string array with context and user name (in this order).
